static DH *get_dh512(void)
{
    static unsigned char dhp_512[] = {
        0xC1, 0x12, 0xF4, 0xF6, 0xF3, 0xE9, 0xA6, 0x7D, 0xE8, 0x1B,
        0xB8, 0x5B, 0x80, 0xAD, 0x75, 0xBC, 0x7D, 0xA1, 0x06, 0xD7,
        0xD4, 0xDD, 0x8E, 0x12, 0x6A, 0xDB, 0x57, 0x0D, 0x38, 0xFF,
        0x61, 0x4C, 0x03, 0x91, 0xF0, 0x45, 0x07, 0xC0, 0xD5, 0x3A,
        0x28, 0xD1, 0xD3, 0x31, 0x8F, 0x2D, 0x4C, 0x69, 0xAA, 0x8E,
        0xAE, 0x9F, 0xC1, 0x0E, 0xD1, 0xE6, 0x7A, 0x48, 0x56, 0xCA,
        0x57, 0x85, 0x8C, 0xF3
    };
    static unsigned char dhg_512[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_512, sizeof(dhp_512), NULL);
    g = BN_bin2bn(dhg_512, sizeof(dhg_512), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
static DH *get_dh2048(void)
{
    static unsigned char dhp_2048[] = {
        0x83, 0xD5, 0xD4, 0xDE, 0xCB, 0xA0, 0x19, 0xA9, 0x28, 0x73,
        0xFA, 0x7D, 0x5F, 0x9A, 0xE9, 0x28, 0x71, 0x53, 0xD5, 0x6E,
        0x3A, 0xA1, 0x38, 0x02, 0x14, 0xA7, 0x8E, 0xE1, 0x79, 0x80,
        0x17, 0x1E, 0xBE, 0xEE, 0x5D, 0x18, 0x88, 0x72, 0x33, 0x52,
        0x8A, 0x3C, 0xC2, 0xFC, 0x56, 0xC8, 0x9B, 0x8A, 0xDB, 0xD1,
        0x63, 0x8A, 0x5D, 0x23, 0x21, 0xEC, 0xEC, 0x4D, 0xCE, 0xA3,
        0xC4, 0x64, 0x21, 0xE8, 0x6B, 0x0D, 0xC8, 0xB3, 0x2F, 0x83,
        0x06, 0xBA, 0xA4, 0x1B, 0x88, 0x53, 0x99, 0x66, 0x88, 0xCA,
        0xD7, 0x57, 0xE1, 0xC8, 0x9E, 0x7D, 0x24, 0x55, 0x8A, 0xE4,
        0xDF, 0x30, 0xA4, 0x01, 0x30, 0x8E, 0x75, 0x73, 0x1C, 0x74,
        0xA6, 0xD4, 0xAD, 0x52, 0x5E, 0x6C, 0x7E, 0x6B, 0x9D, 0x70,
        0xAE, 0x27, 0x4D, 0xDB, 0x36, 0xD5, 0xB1, 0x15, 0x7B, 0xC1,
        0xCA, 0x76, 0x03, 0x52, 0xF0, 0x2C, 0xF8, 0x1B, 0x45, 0xCB,
        0x7B, 0x6B, 0x84, 0xAA, 0xB0, 0xE9, 0x63, 0xF5, 0x62, 0x71,
        0xC5, 0x4F, 0x30, 0x11, 0xC9, 0xDD, 0x3A, 0x37, 0xD8, 0xC5,
        0x8B, 0x5B, 0x6A, 0x26, 0x1F, 0xE7, 0xFA, 0x2E, 0xB1, 0x66,
        0xE6, 0xEF, 0xE6, 0x10, 0x9E, 0xBF, 0x35, 0x39, 0x45, 0x74,
        0x66, 0x50, 0xE1, 0xFA, 0x02, 0x8E, 0xAD, 0x35, 0x91, 0xEA,
        0xDD, 0x97, 0x03, 0x51, 0x6F, 0x76, 0x0B, 0xDE, 0x8E, 0x99,
        0x10, 0x61, 0x4F, 0x51, 0x8F, 0x8D, 0x80, 0x9C, 0x3B, 0x5F,
        0x7F, 0x32, 0x69, 0x16, 0x00, 0x7F, 0x28, 0x2C, 0x77, 0x9B,
        0x50, 0x4E, 0x5A, 0xE7, 0x83, 0x87, 0x6C, 0x58, 0x4F, 0x7F,
        0xA4, 0xA8, 0xAD, 0x41, 0x41, 0xC4, 0xCC, 0x32, 0x36, 0x82,
        0xD6, 0x69, 0xE6, 0xC4, 0x67, 0x25, 0x02, 0xB5, 0xB5, 0xDE,
        0x23, 0x31, 0x70, 0x81, 0x68, 0xE3, 0x11, 0xE5, 0xF6, 0x81,
        0x73, 0xD2, 0xC9, 0x74, 0x1A, 0x3B
    };
    static unsigned char dhg_2048[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_2048, sizeof(dhp_2048), NULL);
    g = BN_bin2bn(dhg_2048, sizeof(dhg_2048), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
